@@ -7,12 +7,12 @@
 #   it under the terms of the GNU General Public License as published by
 #   the Free Software Foundation; either version 3 of the License, or
 #   (at your option) any later version.
-# 
+#
 #   This program is distributed in the hope that it will be useful,
 #   but WITHOUT ANY WARRANTY; without even the implied warranty of
 #   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 #   GNU General Public License for more details.
-# 
+#
 #   You should have received a copy of the GNU General Public License along
 #   with this program.  If not, see <https://www.gnu.org/licenses/>.
 
@@ -41,7 +41,7 @@ from skyfield.nutationlib import iau2000b
 #from skyfield.data import hipparcos
 
 ###### Local application imports ######
-from sfalmanac.lib import config as config
+from sfalmanac.lib import config
 
 #----------------------
 #   initialization
