@@ -634,9 +634,9 @@ def starstab(Date, ts, spad):
     return out
 
 # >>>>>>>>>>>>>>>>>>>>>>>>
-def mp_sunmoon_worker(Date, ts, spad, n):
+def mp_sunmoon_worker(Date, d_valNA, ts, spad, n):
     # split the work by date into 3 separate days
-    sunmoondata = mp_sunmoon(Date, ts, spad, n)      # ===>>> mp_nautical.py
+    sunmoondata = mp_sunmoon(Date, d_valNA, ts, spad, n)      # ===>>> mp_nautical.py
     return sunmoondata
 
 def sunmoontab(Date, ts, spad):
@@ -650,7 +650,7 @@ def sunmoontab(Date, ts, spad):
 
     if config.MULTIpr and config.WINpf:
         # multiprocess sunmoontab values per "Date" simultaneously
-        partial_func = partial(mp_sunmoon_worker, Date, ts, spad)
+        partial_func = partial(mp_sunmoon_worker, Date, config.d_valNA, ts, spad)
 
         try:
             sunmoonlist = pool.map(partial_func, [nn for nn in range(3)], 1)
@@ -761,7 +761,7 @@ def sunmoontabm(Date, ts, spad):
 
     if config.MULTIpr and config.WINpf:
         # multiprocess sunmoontab values per "Date" simultaneously
-        partial_func = partial(mp_sunmoon_worker, Date, ts, spad)
+        partial_func = partial(mp_sunmoon_worker, Date, config.d_valNA, ts, spad)
 
         try:
             sunmoonlist = pool.map(partial_func, [nn for nn in range(3)], 1)
